@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # This code is part of Qiskit.
 #
 # (C) Copyright IBM 2017, 2018.
@@ -15,7 +13,6 @@
 """Represent IBM Quantum Experience account credentials."""
 
 import re
-import warnings
 
 from typing import Dict, Tuple, Optional, Any
 from requests_ntlm import HttpNtlmAuth
@@ -34,7 +31,7 @@ TEMPLATE_IBMQ_HUBS = '{prefix}/Network/{hub}/Groups/{group}/Projects/{project}'
 
 
 class Credentials:
-    """IBM Quantum Experience account credentials.
+    """IBM Quantum Experience account credentials and preferences.
 
     Note:
         By convention, two credentials that have the same hub, group,
@@ -51,7 +48,10 @@ class Credentials:
             project: Optional[str] = None,
             proxies: Optional[Dict] = None,
             verify: bool = True,
-            services: Optional[Dict] = None
+            services: Optional[Dict] = None,
+            access_token: Optional[str] = None,
+            preferences: Optional[Dict] = None,
+            default_provider: Optional[HubGroupProject] = None
     ) -> None:
         """Credentials constructor.
 
@@ -65,29 +65,36 @@ class Credentials:
             proxies: Proxy configuration.
             verify: If ``False``, ignores SSL certificates errors.
             services: Additional services for this account.
+            access_token: IBM Quantum access token.
+            preferences: Application preferences. Used for dictating preferred
+                action in services like the `ExperimentService`.
+            default_provider: Default provider to use.
         """
         self.token = token
+        self.access_token = access_token
         (self.url, self.base_url,
          self.hub, self.group, self.project) = _unify_ibmq_url(
              url, hub, group, project)
         self.websockets_url = websockets_url
         self.proxies = proxies or {}
         self.verify = verify
-
-        # Normalize proxy urls.
-        self._prepend_protocol_if_needed()
+        self.preferences = preferences or {}
+        self.default_provider = default_provider
 
         # Initialize additional service URLs.
         services = services or {}
         self.extractor_url = services.get('extractorsService', None)
         self.experiment_url = services.get('resultsDB', None)
+        self.runtime_url = services.get('runtime', None)
 
     def is_ibmq(self) -> bool:
         """Return whether the credentials represent an IBM Quantum Experience account."""
         return all([self.hub, self.group, self.project])
 
     def __eq__(self, other: object) -> bool:
-        return self.__dict__ == other.__dict__
+        if not isinstance(other, Credentials):
+            return False
+        return (self.token == other.token) & (self.unique_id() == other.unique_id())
 
     def unique_id(self) -> HubGroupProject:
         """Return a value that uniquely identifies these credentials.
@@ -124,26 +131,6 @@ class Credentials:
 
         return request_kwargs
 
-    def _prepend_protocol_if_needed(self) -> None:
-        """Prepend the proxy URLs with protocol if needed."""
-        if 'urls' not in self.proxies:
-            return
-
-        warning_issued = False
-        for key, url in self.proxies['urls'].items():
-            colon_pos = url.find(':')
-            if colon_pos < 0 or re.match(r'[0-9]*$', url[colon_pos+1:]):
-                # If colon not found OR everything after colon are digits (i.e. port number).
-                if not warning_issued:
-                    warnings.warn("Proxy URLs without protocols (e.g. 'http://') "
-                                  "will no longer be supported in the future release.",
-                                  DeprecationWarning, stacklevel=4)
-                    warning_issued = True
-                prepend_str = 'http:'
-                if url[:2] != '//':
-                    prepend_str += '//'
-                self.proxies['urls'][key] = prepend_str + url
-
 
 def _unify_ibmq_url(
         url: str,
