@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # This code is part of Qiskit.
 #
 # (C) Copyright IBM 2017, 2018.
@@ -15,8 +13,7 @@
 """Utilities for reading credentials from environment variables."""
 
 import os
-from collections import OrderedDict
-from typing import Dict, Tuple
+from typing import Dict
 
 from .credentials import Credentials
 from .hubgroupproject import HubGroupProject
@@ -40,7 +37,7 @@ def read_credentials_from_environ() -> Dict[HubGroupProject, Credentials]:
     """
     # The token is the only required parameter.
     if not (os.getenv('QE_TOKEN') and os.getenv('QE_URL')):
-        return OrderedDict()
+        return {}
 
     # Build the credentials based on environment variables.
     credentials_dict = {}
@@ -49,4 +46,4 @@ def read_credentials_from_environ() -> Dict[HubGroupProject, Credentials]:
             credentials_dict[credential_key] = os.getenv(envar_name)
 
     credentials = Credentials(**credentials_dict)  # type: ignore[arg-type]
-    return OrderedDict({credentials.unique_id(): credentials})
+    return {credentials.unique_id(): credentials}
