@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # This code is part of Qiskit.
 #
 # (C) Copyright IBM 2017, 2020.
@@ -16,21 +14,30 @@
 
 import logging
 import warnings
+import copy
 
 from typing import Dict, List, Union, Optional, Any
 from datetime import datetime as python_datetime
 
-from qiskit.qobj import QasmQobj, PulseQobj, validate_qobj_against_schema
-from qiskit.providers.basebackend import BaseBackend  # type: ignore[attr-defined]
+from qiskit.compiler import assemble
+from qiskit.circuit import QuantumCircuit, Parameter, Delay
+from qiskit.circuit.duration import duration_in_dt
+from qiskit.pulse import Schedule, LoConfig
+from qiskit.pulse.channels import PulseChannel
+from qiskit.qobj import QasmQobj, PulseQobj
+from qiskit.qobj.utils import MeasLevel, MeasReturnType
+from qiskit.providers.backend import BackendV1 as Backend
+from qiskit.providers.options import Options
 from qiskit.providers.jobstatus import JobStatus
 from qiskit.providers.models import (BackendStatus, BackendProperties,
                                      PulseDefaults, GateConfig)
 from qiskit.tools.events.pubsub import Publisher
 from qiskit.providers.models import (QasmBackendConfiguration,
                                      PulseBackendConfiguration)
+from qiskit.util import deprecate_arguments
 
 from qiskit.providers.ibmq import accountprovider  # pylint: disable=unused-import
-from .apiconstants import ApiJobShareLevel, ApiJobStatus, API_JOB_FINAL_STATES
+from .apiconstants import ApiJobStatus, API_JOB_FINAL_STATES
 from .api.clients import AccountClient
 from .api.exceptions import ApiError
 from .backendjoblimit import BackendJobLimit
@@ -40,7 +47,7 @@ from .exceptions import (IBMQBackendError, IBMQBackendValueError,
                          IBMQBackendApiError, IBMQBackendApiProtocolError,
                          IBMQBackendJobLimitError)
 from .job import IBMQJob
-from .utils import update_qobj_config, validate_job_tags
+from .utils import validate_job_tags
 from .utils.converters import utc_to_local_all, local_to_utc
 from .utils.json_decoder import decode_pulse_defaults, decode_backend_properties
 from .utils.backend import convert_reservation_data
@@ -49,12 +56,13 @@ from .utils.utils import api_status_to_job_status
 logger = logging.getLogger(__name__)
 
 
-class IBMQBackend(BaseBackend):
+class IBMQBackend(Backend):
     """Backend class interfacing with an IBM Quantum Experience device.
 
-    You can run experiments on a backend using the :meth:`run()` method after
-    assembling them into the :class:`Qobj<qiskit.qobj.Qobj>` format. The
-    :meth:`run()` method returns an :class:`IBMQJob<qiskit.providers.ibmq.job.IBMQJob>`
+    You can run experiments on a backend using the :meth:`run()` method. The
+    :meth:`run()` method takes one or more :class:`~qiskit.circuit.QuantumCircuit`
+    or :class:`~qiskit.pulse.Schedule` and returns
+    an :class:`~qiskit.providers.ibmq.job.IBMQJob`
     instance that represents the submitted job. Each job has a unique job ID, which
     can later be used to retrieve the job. An example of this flow::
 
@@ -62,16 +70,20 @@ class IBMQBackend(BaseBackend):
         from qiskit.circuit.random import random_circuit
 
         provider = IBMQ.load_account()
-        backend = provider.backends.ibmq_vigo
+        backend = provider.backend.ibmq_vigo
         qx = random_circuit(n_qubits=5, depth=4)
-        qobj = assemble(transpile(qx, backend=backend), backend=backend)
-        job = backend.run(qobj)
+        transpiled = transpile(qx, backend=backend)
+        job = backend.run(transpiled)
         retrieved_job = backend.retrieve_job(job.job_id())
 
     Note:
-        You should not instantiate the ``IBMQBackend`` class directly. Instead, use
-        the methods provided by an :class:`AccountProvider` instance to retrieve and handle
-        backends.
+
+        * Unlike :meth:`qiskit.execute`, the :meth:`run` method does not transpile
+          the circuits/schedules for you, so be sure to do so before submitting them.
+
+        * You should not instantiate the ``IBMQBackend`` class directly. Instead, use
+          the methods provided by an :class:`AccountProvider` instance to retrieve and handle
+          backends.
 
     Other methods return information about the backend. For example, the :meth:`status()` method
     returns a :class:`BackendStatus<qiskit.providers.models.BackendStatus>` instance.
@@ -90,6 +102,9 @@ class IBMQBackend(BaseBackend):
         job_limit = backend.job_limit()
     """
 
+    qobj_warning_issued = False
+    id_warning_issued = False
+
     def __init__(
             self,
             configuration: Union[QasmBackendConfiguration, PulseBackendConfiguration],
@@ -117,18 +132,57 @@ class IBMQBackend(BaseBackend):
         self._properties = None
         self._defaults = None
 
+    @classmethod
+    def _default_options(cls) -> Options:
+        """Default runtime options."""
+        return Options(shots=1024, memory=False,
+                       qubit_lo_freq=None, meas_lo_freq=None,
+                       schedule_los=None,
+                       meas_level=MeasLevel.CLASSIFIED,
+                       meas_return=MeasReturnType.AVERAGE,
+                       memory_slots=None, memory_slot_size=100,
+                       rep_time=None, rep_delay=None,
+                       init_qubits=True, use_measure_esp=None)
+
+    @deprecate_arguments({'qobj': 'circuits'})
     def run(
             self,
-            qobj: Union[QasmQobj, PulseQobj],
+            circuits: Union[QasmQobj, PulseQobj, QuantumCircuit, Schedule,
+                            List[Union[QuantumCircuit, Schedule]]],
             job_name: Optional[str] = None,
             job_share_level: Optional[str] = None,
             job_tags: Optional[List[str]] = None,
-            validate_qobj: bool = False
+            experiment_id: Optional[str] = None,
+            header: Optional[Dict] = None,
+            shots: Optional[int] = None,
+            memory: Optional[bool] = None,
+            qubit_lo_freq: Optional[List[int]] = None,
+            meas_lo_freq: Optional[List[int]] = None,
+            schedule_los: Optional[Union[List[Union[Dict[PulseChannel, float], LoConfig]],
+                                         Union[Dict[PulseChannel, float], LoConfig]]] = None,
+            meas_level: Optional[Union[int, MeasLevel]] = None,
+            meas_return: Optional[Union[str, MeasReturnType]] = None,
+            memory_slots: Optional[int] = None,
+            memory_slot_size: Optional[int] = None,
+            rep_time: Optional[int] = None,
+            rep_delay: Optional[float] = None,
+            init_qubits: Optional[bool] = None,
+            parameter_binds: Optional[List[Dict[Parameter, float]]] = None,
+            use_measure_esp: Optional[bool] = None,
+            **run_config: Dict
     ) -> IBMQJob:
-        """Run a Qobj asynchronously.
+        """Run on the backend.
+
+        If a keyword specified here is also present in the ``options`` attribute/object,
+        the value specified here will be used for this run.
 
         Args:
-            qobj: The Qobj to be executed.
+            circuits: An individual or a
+                list of :class:`~qiskit.circuits.QuantumCircuit` or
+                :class:`~qiskit.pulse.Schedule` objects to run on the backend.
+                A :class:`~qiskit.qobj.QasmQobj` or a
+                :class:`~qiskit.qobj.PulseQobj` object is also supported but
+                is deprecated.
             job_name: Custom name to be assigned to the job. This job
                 name can subsequently be used as a filter in the
                 :meth:`jobs()` method. Job names do not need to be unique.
@@ -143,45 +197,151 @@ class IBMQBackend(BaseBackend):
                     * none: The job is not shared at any level.
 
                 If the job share level is not specified, the job is not shared at any level.
-            job_tags: Tags to be assigned to the jobs. The tags can subsequently be used
+            job_tags: Tags to be assigned to the job. The tags can subsequently be used
                 as a filter in the :meth:`jobs()` function call.
-            validate_qobj: If ``True``, run JSON schema validation against the
-                submitted payload
+            experiment_id: Used to add a job to an "experiment", which is a collection
+                of jobs and additional metadata.
+
+            The following arguments are NOT applicable if a Qobj is passed in.
+
+            header: User input that will be attached to the job and will be
+                copied to the corresponding result header. Headers do not affect the run.
+                This replaces the old ``Qobj`` header.
+            shots: Number of repetitions of each circuit, for sampling. Default: 1024
+                or ``max_shots`` from the backend configuration, whichever is smaller.
+            memory: If ``True``, per-shot measurement bitstrings are returned as well
+                (provided the backend supports it). For OpenPulse jobs, only
+                measurement level 2 supports this option.
+            qubit_lo_freq: List of default qubit LO frequencies in Hz. Will be overridden by
+                ``schedule_los`` if set.
+            meas_lo_freq: List of default measurement LO frequencies in Hz. Will be overridden
+                by ``schedule_los`` if set.
+            schedule_los: Experiment LO configurations, frequencies are given in Hz.
+            meas_level: Set the appropriate level of the measurement output for pulse experiments.
+            meas_return: Level of measurement data for the backend to return.
+
+                For ``meas_level`` 0 and 1:
+                    * ``single`` returns information from every shot.
+                    * ``avg`` returns average measurement output (averaged over number of shots).
+            memory_slots: Number of classical memory slots to use.
+            memory_slot_size: Size of each memory slot if the output is Level 0.
+            rep_time: Time per program execution in seconds. Must be from the list provided
+                by the backend (``backend.configuration().rep_times``).
+                Defaults to the first entry.
+            rep_delay: Delay between programs in seconds. Only supported on certain
+                backends (if ``backend.configuration().dynamic_reprate_enabled=True``).
+                If supported, ``rep_delay`` will be used instead of ``rep_time`` and must be
+                from the range supplied
+                by the backend (``backend.configuration().rep_delay_range``). Default is given by
+                ``backend.configuration().default_rep_delay``.
+            init_qubits: Whether to reset the qubits to the ground state for each shot.
+                Default: ``True``.
+            parameter_binds: List of Parameter bindings over which the set of experiments will be
+                executed. Each list element (bind) should be of the form
+                {Parameter1: value1, Parameter2: value2, ...}. All binds will be
+                executed across all experiments; e.g., if parameter_binds is a
+                length-n list, and there are m experiments, a total of m x n
+                experiments will be run (one for each experiment/bind pair).
+            use_measure_esp: Whether to use excited state promoted (ESP) readout for measurements
+                which are the terminal instruction to a qubit. ESP readout can offer higher fidelity
+                than standard measurement sequences. See
+                `here <https://arxiv.org/pdf/2008.08571.pdf>`_.
+                Default: ``True`` if backend supports ESP readout, else ``False``. Backend support
+                for ESP readout is determined by the flag ``measure_esp_enabled`` in
+                ``backend.configuration()``.
+            **run_config: Extra arguments used to configure the run.
 
         Returns:
-            The job to be executed, an instance derived from BaseJob.
+            The job to be executed.
 
         Raises:
             IBMQBackendApiError: If an unexpected error occurred while submitting
                 the job.
             IBMQBackendApiProtocolError: If an unexpected value received from
                  the server.
-            IBMQBackendValueError: If an input parameter value is not valid.
+            IBMQBackendValueError:
+                - If an input parameter value is not valid.
+                - If ESP readout is used and the backend does not support this.
         """
         # pylint: disable=arguments-differ
         if job_share_level:
-            try:
-                api_job_share_level = ApiJobShareLevel(job_share_level.lower())
-            except ValueError:
-                valid_job_share_levels_str = ', '.join(level.value for level in ApiJobShareLevel)
-                raise IBMQBackendValueError(
-                    '"{}" is not a valid job share level. '
-                    'Valid job share levels are: {}.'
-                    .format(job_share_level, valid_job_share_levels_str)) from None
-        else:
-            api_job_share_level = ApiJobShareLevel.NONE
+            warnings.warn("The `job_share_level` keyword is no longer supported "
+                          "and will be removed in a future release.",
+                          Warning, stacklevel=3)
 
         validate_job_tags(job_tags, IBMQBackendValueError)
-        if validate_qobj:
-            validate_qobj_against_schema(qobj)
-        return self._submit_job(qobj, job_name, api_job_share_level, job_tags)
+
+        sim_method = None
+        if self.configuration().simulator:
+            sim_method = getattr(self.configuration(), 'simulation_method', None)
+
+        measure_esp_enabled = getattr(self.configuration(), "measure_esp_enabled", False)
+        # set ``use_measure_esp`` to backend value if not set by user
+        if use_measure_esp is None:
+            use_measure_esp = measure_esp_enabled
+        if use_measure_esp and not measure_esp_enabled:
+            raise IBMQBackendValueError(
+                "ESP readout not supported on this device. Please make sure the flag "
+                "'use_measure_esp' is unset or set to 'False'."
+            )
+
+        if not self.configuration().simulator:
+            self._deprecate_id_instruction(circuits)
+
+        if isinstance(circuits, (QasmQobj, PulseQobj)):
+            if not self.qobj_warning_issued:
+                warnings.warn("Passing a Qobj to Backend.run is deprecated and will "
+                              "be removed in a future release. Please pass in circuits "
+                              "or pulse schedules instead.", DeprecationWarning,
+                              stacklevel=3)  # need level 3 because of decorator
+                self.qobj_warning_issued = True
+            qobj = circuits
+            if sim_method and not hasattr(qobj.config, 'method'):
+                qobj.config.method = sim_method
+        else:
+            qobj_header = run_config.pop('qobj_header', None)
+            header = header or qobj_header
+            run_config_dict = self._get_run_config(
+                qobj_header=header,
+                shots=shots,
+                memory=memory,
+                qubit_lo_freq=qubit_lo_freq,
+                meas_lo_freq=meas_lo_freq,
+                schedule_los=schedule_los,
+                meas_level=meas_level,
+                meas_return=meas_return,
+                memory_slots=memory_slots,
+                memory_slot_size=memory_slot_size,
+                rep_time=rep_time,
+                rep_delay=rep_delay,
+                init_qubits=init_qubits,
+                use_measure_esp=use_measure_esp,
+                **run_config)
+            if parameter_binds:
+                run_config_dict['parameter_binds'] = parameter_binds
+            if sim_method and 'method' not in run_config_dict:
+                run_config_dict['method'] = sim_method
+            qobj = assemble(circuits, self, **run_config_dict)
+
+        return self._submit_job(qobj, job_name, job_tags, experiment_id)
+
+    def _get_run_config(self, **kwargs: Any) -> Dict:
+        """Return the consolidated runtime configuration."""
+        run_config_dict = copy.copy(self.options.__dict__)
+        for key, val in kwargs.items():
+            if val is not None:
+                run_config_dict[key] = val
+                if key not in self.options.__dict__ and not isinstance(self, IBMQSimulator):
+                    warnings.warn(f"{key} is not a recognized runtime"  # type: ignore[unreachable]
+                                  f" option and may be ignored by the backend.", stacklevel=4)
+        return run_config_dict
 
     def _submit_job(
             self,
             qobj: Union[QasmQobj, PulseQobj],
             job_name: Optional[str] = None,
-            job_share_level: Optional[ApiJobShareLevel] = None,
-            job_tags: Optional[List[str]] = None
+            job_tags: Optional[List[str]] = None,
+            experiment_id: Optional[str] = None
     ) -> IBMQJob:
         """Submit the Qobj to the backend.
 
@@ -191,11 +351,11 @@ class IBMQBackend(BaseBackend):
                 name can subsequently be used as a filter in the
                 ``jobs()``method.
                 Job names do not need to be unique.
-            job_share_level: Level the job should be shared at.
             job_tags: Tags to be assigned to the job.
+            experiment_id: Used to add a job to an experiment.
 
         Returns:
-            The job to be executed, an instance derived from BaseJob.
+            The job to be executed.
 
         Events:
             ibmq.job.start: The job has started.
@@ -216,8 +376,8 @@ class IBMQBackend(BaseBackend):
                 backend_name=self.name(),
                 qobj_dict=qobj_dict,
                 job_name=job_name,
-                job_share_level=job_share_level,
-                job_tags=job_tags)
+                job_tags=job_tags,
+                experiment_id=experiment_id)
         except ApiError as ex:
             if 'Error code: 3458' in str(ex):
                 raise IBMQBackendJobLimitError('Error submitting job: {}'.format(str(ex))) from ex
@@ -247,6 +407,14 @@ class IBMQBackend(BaseBackend):
     ) -> Optional[BackendProperties]:
         """Return the backend properties, subject to optional filtering.
 
+        This data describes qubits properties (such as T1 and T2),
+        gates properties (such as gate length and error), and other general
+        properties of the backend.
+
+        The schema for backend properties can be found in
+        `Qiskit/ibm-quantum-schemas
+        <https://github.com/Qiskit/ibm-quantum-schemas/blob/main/schemas/backend_properties_schema.json>`_.
+
         Args:
             refresh: If ``True``, re-query the server for the backend properties.
                 Otherwise, return a cached version.
@@ -269,8 +437,6 @@ class IBMQBackend(BaseBackend):
             raise TypeError("'{}' is not of type 'datetime'.")
 
         if datetime:
-            warnings.warn('Unless a UTC timezone information is present, the parameter `datetime`'
-                          'is now expected to be in local time instead of UTC.', stacklevel=2)
             datetime = local_to_utc(datetime)
 
         if datetime or refresh or self._properties is None:
@@ -288,6 +454,11 @@ class IBMQBackend(BaseBackend):
     def status(self) -> BackendStatus:
         """Return the backend status.
 
+        Note:
+            If the returned :class:`~qiskit.providers.models.BackendStatus`
+            instance has ``operational=True`` but ``status_msg="internal"``,
+            then the backend is accepting jobs but not processing them.
+
         Returns:
             The status of the backend.
 
@@ -306,6 +477,10 @@ class IBMQBackend(BaseBackend):
     def defaults(self, refresh: bool = False) -> Optional[PulseDefaults]:
         """Return the pulse defaults for the backend.
 
+        The schema for default pulse configuration can be found in
+        `Qiskit/ibm-quantum-schemas
+        <https://github.com/Qiskit/ibm-quantum-schemas/blob/main/schemas/default_pulse_configuration_schema.json>`_.
+
         Args:
             refresh: If ``True``, re-query the server for the backend pulse defaults.
                 Otherwise, return a cached version.
@@ -313,9 +488,6 @@ class IBMQBackend(BaseBackend):
         Returns:
             The backend pulse defaults or ``None`` if the backend does not support pulse.
         """
-        if not self.configuration().open_pulse:
-            return None
-
         if refresh or self._defaults is None:
             api_defaults = self._api_client.backend_pulse_defaults(self.name())
             if api_defaults:
@@ -407,6 +579,7 @@ class IBMQBackend(BaseBackend):
             end_datetime: Optional[python_datetime] = None,
             job_tags: Optional[List[str]] = None,
             job_tags_operator: Optional[str] = "OR",
+            experiment_id: Optional[str] = None,
             descending: bool = True,
             db_filter: Optional[Dict[str, Any]] = None
     ) -> List[IBMQJob]:
@@ -442,6 +615,7 @@ class IBMQBackend(BaseBackend):
                       specified in ``job_tags`` to be included.
                     * If "OR" is specified, then a job only needs to have any
                       of the tags specified in ``job_tags`` to be included.
+            experiment_id: Filter by job experiment ID.
             descending: If ``True``, return the jobs in descending order of the job
                 creation date (newest first). If ``False``, return in ascending order.
             db_filter: A `loopback-based filter
@@ -464,10 +638,11 @@ class IBMQBackend(BaseBackend):
         Raises:
             IBMQBackendValueError: If a keyword value is not recognized.
         """
-        return self._provider.backends.jobs(
-            limit, skip, self.name(), status,
-            job_name, start_datetime, end_datetime, job_tags, job_tags_operator,
-            descending, db_filter)
+        return self._provider.backend.jobs(
+            limit=limit, skip=skip, backend_name=self.name(), status=status,
+            job_name=job_name, start_datetime=start_datetime, end_datetime=end_datetime,
+            job_tags=job_tags, job_tags_operator=job_tags_operator,
+            experiment_id=experiment_id, descending=descending, db_filter=db_filter)
 
     def active_jobs(self, limit: int = 10) -> List[IBMQJob]:
         """Return the unfinished jobs submitted to this backend.
@@ -502,7 +677,7 @@ class IBMQBackend(BaseBackend):
         Raises:
             IBMQBackendError: If job retrieval failed.
         """
-        job = self._provider.backends.retrieve_job(job_id)
+        job = self._provider.backend.retrieve_job(job_id)
         job_backend = job.backend()
 
         if self.name() != job_backend.name():
@@ -526,8 +701,8 @@ class IBMQBackend(BaseBackend):
         If start_datetime and/or end_datetime is specified, reservations with
         time slots that overlap with the specified time window will be returned.
 
-        Some of the reservation information, such as scheduling mode, is only
-        available if you are the owner of the reservation.
+        Some of the reservation information is only available if you are the
+        owner of the reservation.
 
         Args:
             start_datetime: Filter by the given start date/time, in local timezone.
@@ -542,6 +717,21 @@ class IBMQBackend(BaseBackend):
             self.name(), start_datetime, end_datetime)
         return convert_reservation_data(raw_response, self.name())
 
+    def configuration(self) -> Union[QasmBackendConfiguration, PulseBackendConfiguration]:
+        """Return the backend configuration.
+
+        Backend configuration contains fixed information about the backend, such
+        as its name, number of qubits, basis gates, coupling map, quantum volume, etc.
+
+        The schema for backend configuration can be found in
+        `Qiskit/ibm-quantum-schemas
+        <https://github.com/Qiskit/ibm-quantum-schemas/blob/main/schemas/backend_configuration_schema.json>`_.
+
+        Returns:
+            The configuration for the backend.
+        """
+        return self._configuration
+
     def __repr__(self) -> str:
         credentials_info = ''
         if self.hub:
@@ -550,10 +740,103 @@ class IBMQBackend(BaseBackend):
         return "<{}('{}') from IBMQ({})>".format(
             self.__class__.__name__, self.name(), credentials_info)
 
+    def _deprecate_id_instruction(
+            self,
+            circuits: Union[QasmQobj, PulseQobj, QuantumCircuit, Schedule,
+                            List[Union[QuantumCircuit, Schedule]]]
+    ) -> None:
+        """Raise a DeprecationWarning if any circuit contains an 'id' instruction.
+
+        Additionally, if 'delay' is a 'supported_instruction', replace each 'id'
+        instruction (in-place) with the equivalent ('sx'-length) 'delay' instruction.
+
+        Args:
+            circuits: The individual or list of :class:`~qiskit.circuits.QuantumCircuit` or
+                :class:`~qiskit.pulse.Schedule` objects passed to
+                :meth:`IBMQBackend.run()<IBMQBackend.run>`. Modified in-place.
+
+        Returns:
+            None
+        """
+
+        if isinstance(circuits, PulseQobj):
+            return
+
+        id_support = 'id' in getattr(self.configuration(), 'basis_gates', [])
+        delay_support = 'delay' in getattr(self.configuration(), 'supported_instructions', [])
+
+        if not delay_support:
+            return
+
+        if isinstance(circuits, QasmQobj):
+            circuit_has_id = any(instr.name == 'id'
+                                 for experiment in circuits.experiments
+                                 for instr in experiment.instructions)
+        else:
+            if not isinstance(circuits, List):
+                circuits = [circuits]
+
+            circuit_has_id = any(instr.name == 'id'
+                                 for circuit in circuits
+                                 if isinstance(circuit, QuantumCircuit)
+                                 for instr, qargs, cargs in circuit.data)
+
+        if not circuit_has_id:
+            return
+
+        if not self.id_warning_issued:
+            if id_support and delay_support:
+                warnings.warn("Support for the 'id' instruction has been deprecated "
+                              "from IBM hardware backends. Any 'id' instructions "
+                              "will be replaced with their equivalent 'delay' instruction. "
+                              "Please use the 'delay' instruction instead.", DeprecationWarning,
+                              stacklevel=4)
+            else:
+                warnings.warn("Support for the 'id' instruction has been removed "
+                              "from IBM hardware backends. Any 'id' instructions "
+                              "will be replaced with their equivalent 'delay' instruction. "
+                              "Please use the 'delay' instruction instead.", DeprecationWarning,
+                              stacklevel=4)
+
+            self.id_warning_issued = True
+
+        dt_in_s = self.configuration().dt
+
+        if isinstance(circuits, QasmQobj):
+            for experiment in circuits.experiments:
+                for instr in experiment.instructions:
+                    if instr.name == 'id':
+                        sx_duration = self.properties().gate_length('sx', instr.qubits[0])
+                        sx_duration_in_dt = duration_in_dt(sx_duration, dt_in_s)
+
+                        instr.name = 'delay'
+                        instr.params = [sx_duration_in_dt]
+        else:
+            for circuit in circuits:
+                if isinstance(circuit, Schedule):
+                    continue
+
+                for idx, (instr, qargs, cargs) in enumerate(circuit.data):
+                    if instr.name == 'id':
+
+                        sx_duration = self.properties().gate_length('sx', qargs[0].index)
+                        sx_duration_in_dt = duration_in_dt(sx_duration, dt_in_s)
+
+                        delay_instr = Delay(sx_duration_in_dt)
+
+                        circuit.data[idx] = (delay_instr, qargs, cargs)
+
 
 class IBMQSimulator(IBMQBackend):
     """Backend class interfacing with an IBM Quantum Experience simulator."""
 
+    @classmethod
+    def _default_options(cls) -> Options:
+        """Default runtime options."""
+        options = super()._default_options()
+        options.update_options(noise_model=None, seed_simulator=None)
+        return options
+
     def properties(
             self,
             refresh: bool = False,
@@ -562,22 +845,28 @@ class IBMQSimulator(IBMQBackend):
         """Return ``None``, simulators do not have backend properties."""
         return None
 
-    def run(
+    @deprecate_arguments({'qobj': 'circuits'})
+    def run(    # type: ignore[override]
             self,
-            qobj: Union[QasmQobj, PulseQobj],
+            circuits: Union[QasmQobj, PulseQobj, QuantumCircuit, Schedule,
+                            List[Union[QuantumCircuit, Schedule]]],
             job_name: Optional[str] = None,
             job_share_level: Optional[str] = None,
             job_tags: Optional[List[str]] = None,
-            validate_qobj: bool = False,
+            experiment_id: Optional[str] = None,
             backend_options: Optional[Dict] = None,
-            noise_model: Any = None
+            noise_model: Any = None,
+            **kwargs: Dict
     ) -> IBMQJob:
         """Run a Qobj asynchronously.
 
         Args:
-            qobj: The Qobj to be executed.
-            backend_options: Backend options.
-            noise_model: Noise model.
+            circuits: An individual or a
+                list of :class:`~qiskit.circuits.QuantumCircuit` or
+                :class:`~qiskit.pulse.Schedule` objects to run on the backend.
+                A :class:`~qiskit.qobj.QasmQobj` or a
+                :class:`~qiskit.qobj.PulseQobj` object is also supported but
+                is deprecated.
             job_name: Custom name to be assigned to the job. This job
                 name can subsequently be used as a filter in the
                 :meth:`jobs` method. Job names do not need to be unique.
@@ -585,16 +874,38 @@ class IBMQSimulator(IBMQBackend):
                 global level (see :meth:`IBMQBackend.run()<IBMQBackend.run>` for more details).
             job_tags: Tags to be assigned to the jobs. The tags can subsequently be used
                 as a filter in the :meth:`IBMQBackend.jobs()<IBMQBackend.jobs>` method.
-            validate_qobj: If ``True``, run JSON schema validation against the
-                submitted payload
+            experiment_id: Used to add a job to an "experiment", which is a collection
+                of jobs and additional metadata.
+            backend_options: DEPRECATED dictionary of backend options for the execution.
+            noise_model: Noise model.
+            kwargs: Additional runtime configuration options. They take
+                precedence over options of the same names specified in `backend_options`.
 
         Returns:
-            The job to be executed, an instance derived from ``BaseJob``.
+            The job to be executed.
         """
         # pylint: disable=arguments-differ
-        qobj = update_qobj_config(qobj, backend_options, noise_model)
-        return super(IBMQSimulator, self).run(qobj, job_name, job_share_level, job_tags,
-                                              validate_qobj)
+        if job_share_level:
+            warnings.warn("The `job_share_level` keyword is no longer supported "
+                          "and will be removed in a future release.",
+                          Warning, stacklevel=3)
+        if backend_options is not None:
+            warnings.warn("Use of `backend_options` is deprecated and will "
+                          "be removed in a future release."
+                          "You can now pass backend options as key-value pairs to the "
+                          "run() method. For example: backend.run(circs, shots=2048).",
+                          DeprecationWarning, stacklevel=2)
+        backend_options = backend_options or {}
+        run_config = copy.deepcopy(backend_options)
+        if noise_model:
+            try:
+                noise_model = noise_model.to_dict()
+            except AttributeError:
+                pass
+        run_config.update(kwargs)
+        return super().run(circuits, job_name=job_name,
+                           job_tags=job_tags, experiment_id=experiment_id,
+                           noise_model=noise_model, **run_config)
 
 
 class IBMQRetiredBackend(IBMQBackend):
@@ -623,6 +934,11 @@ class IBMQRetiredBackend(IBMQBackend):
             pending_jobs=0,
             status_msg='This backend is no longer available.')
 
+    @classmethod
+    def _default_options(cls) -> Options:
+        """Default runtime options."""
+        return Options()
+
     def properties(
             self,
             refresh: bool = False,
@@ -658,15 +974,13 @@ class IBMQRetiredBackend(IBMQBackend):
     ) -> List[BackendReservation]:
         return []
 
-    def run(
+    def run(    # type: ignore[override]
             self,
-            qobj: Union[QasmQobj, PulseQobj],
-            job_name: Optional[str] = None,
-            job_share_level: Optional[str] = None,
-            job_tags: Optional[List[str]] = None,
-            validate_qobj: bool = False
+            *args: Any,
+            **kwargs: Any
     ) -> None:
         """Run a Qobj."""
+        # pylint: disable=arguments-differ
         raise IBMQBackendError('This backend ({}) is no longer available.'.format(self.name()))
 
     @classmethod
