@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # This code is part of Qiskit.
 #
 # (C) Copyright IBM 2017, 2020.
@@ -23,12 +21,15 @@ from threading import Event
 from queue import Empty
 import dateutil.parser
 
-from qiskit.providers import BaseJob  # type: ignore[attr-defined]
+from qiskit.providers.job import JobV1 as Job
 from qiskit.providers.jobstatus import JOB_FINAL_STATES, JobStatus
 from qiskit.providers.models import BackendProperties
 from qiskit.qobj import QasmQobj, PulseQobj
 from qiskit.result import Result
 from qiskit.providers.ibmq import ibmqbackend  # pylint: disable=unused-import
+from qiskit.assembler.disassemble import disassemble
+from qiskit.circuit.quantumcircuit import QuantumCircuit
+from qiskit.pulse import Schedule
 
 from ..apiconstants import ApiJobStatus, ApiJobKind
 from ..api.clients import AccountClient
@@ -45,7 +46,7 @@ from .utils import build_error_report, api_to_job_error, get_cancel_status
 logger = logging.getLogger(__name__)
 
 
-class IBMQJob(BaseJob):
+class IBMQJob(Job):
     """Representation of a job that executes on an IBM Quantum Experience backend.
 
     The job may be executed on a simulator or a real device. A new ``IBMQJob``
@@ -97,7 +98,7 @@ class IBMQJob(BaseJob):
     which is a supported attribute.
     """
 
-    _data = {}
+    _data = {}  # type: Dict
 
     _executor = futures.ThreadPoolExecutor()
     """Threads used for asynchronous processing."""
@@ -119,6 +120,7 @@ class IBMQJob(BaseJob):
             run_mode: Optional[str] = None,
             share_level: Optional[str] = None,
             client_info: Optional[Dict[str, str]] = None,
+            experiment_id: Optional[str] = None,
             **kwargs: Any
     ) -> None:
         """IBMQJob constructor.
@@ -139,6 +141,7 @@ class IBMQJob(BaseJob):
             run_mode: Scheduling mode the job runs in.
             share_level: Level the job can be shared with.
             client_info: Client version.
+            experiment_id: ID of the experiment this job is part of.
             kwargs: Additional job attributes.
         """
         self._backend = backend
@@ -159,7 +162,8 @@ class IBMQJob(BaseJob):
             self._get_status_position(status, kwargs.pop('info_queue', None))
         self._use_object_storage = (self._kind == ApiJobKind.QOBJECT_STORAGE)
         self._share_level = share_level
-        self.client_version = client_info
+        self._set_client_version(client_info)
+        self._experiment_id = experiment_id
         self._set_result(result)
 
         self._data = {}
@@ -171,6 +175,7 @@ class IBMQJob(BaseJob):
         # Properties used for caching.
         self._cancelled = False
         self._job_error_msg = None  # type: Optional[str]
+        self._refreshed = False
 
     def qobj(self) -> Optional[Union[QasmQobj, PulseQobj]]:
         """Return the Qobj for this job.
@@ -182,17 +187,13 @@ class IBMQJob(BaseJob):
             IBMQJobApiError: If an unexpected error occurred when retrieving
                 job information from the server.
         """
-        if not self._kind:
-            return None
-
-        # pylint: disable=access-member-before-definition,attribute-defined-outside-init
-        if not self._qobj:  # type: ignore[has-type]
-            with api_to_job_error():
-                qobj = self._api_client.job_download_qobj(
-                    self.job_id(), self._use_object_storage)
-                self._qobj = dict_to_qobj(qobj)
-
-        return self._qobj
+        warnings.warn("The ``IBMQJob.qobj()`` method is deprecated and will "
+                      "be removed in a future release. You can now pass circuits "
+                      "to ``IBMQBackend.run()`` and use ``IBMQJob.circuits()``, "
+                      "``IBMQJob.backend_options()``, and ``IBMQJob.header()`` to retrieve "
+                      "circuits, run configuration, and Qobj header, respectively.",
+                      DeprecationWarning, stacklevel=2)
+        return self._get_qobj()
 
     def properties(self) -> Optional[BackendProperties]:
         """Return the backend properties for this job.
@@ -283,7 +284,7 @@ class IBMQJob(BaseJob):
             if not partial or not self._result or not self._result.results:
                 error_message = self.error_message()
                 if '\n' in error_message:
-                    error_message = ". Use job.error_message() to get more details"
+                    error_message = ". Use the error_message() method to get more details"
                 else:
                     error_message = ": " + error_message
                 raise IBMQJobFailureError(
@@ -626,9 +627,10 @@ class IBMQJob(BaseJob):
         Returns:
             The share level of the job.
         """
-        if not self._share_level:
-            self.refresh()
-        return self._share_level
+        warnings.warn("`IBMQJob.share_level()` method is no longer supported "
+                      "and will be removed in a future release.",
+                      Warning, stacklevel=2)
+        return 'none'
 
     def time_per_step(self) -> Optional[Dict]:
         """Return the date and time information on each step of the job processing.
@@ -686,7 +688,7 @@ class IBMQJob(BaseJob):
             Client version in dictionary format, where the key is the name
                 of the client and the value is the version.
         """
-        if not self._client_version:
+        if not self._client_version and not self._refreshed:
             self.refresh()
         return self._client_version
 
@@ -694,6 +696,17 @@ class IBMQJob(BaseJob):
     def client_version(self, data: Dict[str, str]) -> None:
         """Set client version.
 
+        Args:
+            data: Client version.
+        """
+        warnings.warn('The ``client_version`` setter method is deprecated and '
+                      'will be removed in a future release.',
+                      DeprecationWarning, stacklevel=2)
+        self._set_client_version(data)
+
+    def _set_client_version(self, data: Dict[str, str]) -> None:
+        """Set client version.
+
         Args:
             data: Client version.
         """
@@ -707,23 +720,30 @@ class IBMQJob(BaseJob):
         else:
             self._client_version = {}
 
+    @property
+    def experiment_id(self) -> str:
+        """Return the experiment ID.
+
+        Returns:
+            ID of the experiment this job is part of.
+        """
+        if not self._experiment_id and not self._refreshed:
+            self.refresh()
+        return self._experiment_id
+
     def submit(self) -> None:
-        """Submit this job to an IBM Quantum Experience backend.
+        """Unsupported method.
 
         Note:
-            This function is deprecated, please use
-            :meth:`IBMQBackend.run()<qiskit.providers.ibmq.ibmqbackend.IBMQBackend.run()>`
+            This method is not supported, please use
+            :meth:`~qiskit.providers.ibmq.ibmqbackend.IBMQBackend.run`
             to submit a job.
 
         Raises:
-            IBMQJobInvalidStateError: If the job has already been submitted.
+            NotImplementedError: Upon invocation.
         """
-        if self.job_id() is not None:
-            raise IBMQJobInvalidStateError(
-                'The job {} has already been submitted.'.format(self.job_id()))
-
-        warnings.warn("job.submit() is deprecated. Please use "
-                      "IBMQBackend.run() to submit a job.", DeprecationWarning, stacklevel=2)
+        raise NotImplementedError("job.submit() is not supported. Please use "
+                                  "IBMQBackend.run() to submit a job.")
 
     def refresh(self) -> None:
         """Obtain the latest job information from the server.
@@ -758,40 +778,58 @@ class IBMQJob(BaseJob):
         self._use_object_storage = (self._kind == ApiJobKind.QOBJECT_STORAGE)
         self._status, self._queue_info = \
             self._get_status_position(self._api_status, api_response.pop('info_queue', None))
-        self._share_level = api_response.pop('share_level', 'none')
-        self.client_version = api_response.pop('client_info', None)
+        self._set_client_version(api_response.pop('client_info', None))
         self._set_result(api_response.pop('result', None))
+        self._experiment_id = api_response.pop('experiment_id', None)
 
         for key, value in api_response.items():
             self._data[key + '_'] = value
+        self._refreshed = True
 
-    def to_dict(self) -> Dict:
-        """Serialize the model into a Python dict of simple types.
-
-        Note:
-            This is a unsupported method and will be removed in the next release.
+    def circuits(self) -> List[Union[QuantumCircuit, Schedule]]:
+        """Return the circuits or pulse schedules for this job.
 
         Returns:
-            An empty dictionary.
+            The circuits or pulse schedules for this job. An empty list
+            is returned if the circuits cannot be retrieved (for example, if
+            the job uses an old format that is no longer supported).
         """
-        warnings.warn("IBMQJob.to_dict() is not supported and may not work properly. "
-                      "It will be removed in the next release.",
-                      DeprecationWarning, stacklevel=2)
-        return {}
+        qobj = self._get_qobj()
+        if not qobj:
+            return []
+        circuits, _, _ = disassemble(qobj)
+        return circuits
 
-    @classmethod
-    def from_dict(cls, data: Any) -> 'IBMQJob':
-        """Deserialize a dictionary of simple types into an instance of this class.
+    def backend_options(self) -> Dict[str, Any]:
+        """Return the backend configuration options used for this job.
 
-        Args:
-            data: Data to be deserialized.
+        Options that are not applicable to the job execution are not returned.
+        Some but not all of the options with default values are returned.
+        You can use :attr:`qiskit.providers.ibmq.IBMQBackend.options` to see
+        all backend options.
 
         Returns:
-            An instance of this class.
+            Backend options used for this job. An empty dictionary
+            is returned if the options cannot be retrieved.
         """
-        warnings.warn("IBMQJob.from_dict() is deprecated and will be removed in the next release. ",
-                      DeprecationWarning, stacklevel=2)
-        return cls(**data)
+        qobj = self._get_qobj()
+        if not qobj:
+            return {}
+        _, options, _ = disassemble(qobj)
+        return options
+
+    def header(self) -> Dict:
+        """Return the user header specified for this job.
+
+        Returns:
+            User header specified for this job. An empty dictionary
+            is returned if the header cannot be retrieved.
+        """
+        qobj = self._get_qobj()
+        if not qobj:
+            return {}
+        _, _, header = disassemble(qobj)
+        return header
 
     def wait_for_final_state(
             self,
@@ -890,7 +928,7 @@ class IBMQJob(BaseJob):
 
         return self._status in required_status
 
-    def _retrieve_result(self, refresh: bool = False):
+    def _retrieve_result(self, refresh: bool = False) -> None:
         """Retrieve the job result response.
 
         Args:
@@ -936,16 +974,9 @@ class IBMQJob(BaseJob):
             self._result = None
             return
         raw_data['client_version'] = self.client_version
-        # TODO Stop checking Terra version when it's released.
-        from qiskit.version import __version__ as terra_version
-        if terra_version >= '0.15.0':
-            decode_result(raw_data)
-        # if 'date' in raw_data:
-        #     raw_data['date'] = utc_to_local(raw_data['date'])
+        decode_result(raw_data)
         try:
             self._result = Result.from_dict(raw_data)
-            if hasattr(self._result, 'date'):
-                self._result.date = utc_to_local(self._result.date)
         except (KeyError, TypeError) as err:
             if not self._kind:
                 raise IBMQJobInvalidStateError(
@@ -1062,6 +1093,27 @@ class IBMQJob(BaseJob):
 
         return status, queue_info
 
+    def _get_qobj(self) -> Optional[Union[QasmQobj, PulseQobj]]:
+        """Return the Qobj for this job.
+
+        Returns:
+            The Qobj for this job, or ``None`` if the job does not have a Qobj.
+
+        Raises:
+            IBMQJobApiError: If an unexpected error occurred when retrieving
+                job information from the server.
+        """
+        if not self._kind:
+            return None
+
+        if not self._qobj:
+            with api_to_job_error():
+                qobj = self._api_client.job_download_qobj(
+                    self.job_id(), self._use_object_storage)
+                self._qobj = dict_to_qobj(qobj)
+
+        return self._qobj
+
     def __getattr__(self, name: str) -> Any:
         try:
             return self._data[name]
