@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # This code is part of Qiskit.
 #
 # (C) Copyright IBM 2019, 2020.
@@ -21,10 +19,10 @@ import time
 import logging
 import uuid
 import threading
+import warnings
 
 from qiskit.circuit import QuantumCircuit
 from qiskit.pulse import Schedule
-from qiskit.compiler import assemble
 from qiskit.qobj import QasmQobj, PulseQobj
 from qiskit.providers.jobstatus import JobStatus
 from qiskit.providers.ibmq.apiconstants import ApiJobShareLevel
@@ -86,9 +84,9 @@ class ManagedJobSet:
             experiment_list: Union[List[List[QuantumCircuit]], List[List[Schedule]]],
             backend: IBMQBackend,
             executor: ThreadPoolExecutor,
-            job_share_level: ApiJobShareLevel,
+            job_share_level: Optional[ApiJobShareLevel] = None,
             job_tags: Optional[List[str]] = None,
-            **assemble_config: Any
+            **run_config: Any
     ) -> None:
         """Execute a list of circuits or pulse schedules on a backend.
 
@@ -98,13 +96,18 @@ class ManagedJobSet:
             executor: The thread pool used to submit jobs asynchronously.
             job_share_level: Job share level.
             job_tags: Tags to be assigned to the job.
-            assemble_config: Additional arguments used to configure the Qobj
+            run_config: Additional arguments used to configure the Qobj
                 assembly. Refer to the :func:`qiskit.compiler.assemble` documentation
                 for details on these arguments.
 
         Raises:
             IBMQJobManagerInvalidStateError: If the jobs were already submitted.
         """
+        if job_share_level:
+            warnings.warn("The `job_share_level` keyword is no longer supported "
+                          "and will be removed in a future release.",
+                          Warning, stacklevel=2)
+
         if self._managed_jobs:
             raise IBMQJobManagerInvalidStateError(
                 'The jobs for this managed job set have already been submitted.')
@@ -116,13 +119,12 @@ class ManagedJobSet:
         exp_index = 0
         total_jobs = len(experiment_list)
         for i, experiments in enumerate(experiment_list):
-            qobj = assemble(experiments, backend=backend, **assemble_config)
             job_name = JOB_SET_NAME_FORMATTER.format(self._name, i)
             mjob = ManagedJob(experiments_count=len(experiments), start_index=exp_index)
             logger.debug("Submitting job %s/%s for job set %s", i+1, total_jobs, self._name)
-            mjob.submit(qobj=qobj, job_name=job_name, backend=backend,
-                        executor=executor, job_share_level=job_share_level,
-                        job_tags=self._tags+[self._id_long], submit_lock=self._job_submit_lock)
+            mjob.submit(experiments, job_name=job_name, backend=backend,
+                        executor=executor, job_tags=self._tags+[self._id_long],
+                        submit_lock=self._job_submit_lock, **run_config)
             logger.debug("Job %s submitted", i+1)
             self._managed_jobs.append(mjob)
             exp_index += len(experiments)
@@ -149,7 +151,7 @@ class ManagedJobSet:
         jobs = []  # type: List[IBMQJob]
         page_limit = 1000
         while True:
-            job_page = provider.backends.jobs(    # type: ignore[attr-defined]
+            job_page = provider.backend.jobs(    # type: ignore[attr-defined]
                 skip=len(jobs), limit=page_limit, job_tags=[self._id_long])
             jobs += job_page
             if len(job_page) < page_limit:
