@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # This code is part of Qiskit.
 #
 # (C) Copyright IBM 2019, 2020.
@@ -58,7 +56,7 @@ def requires_submit(func: Callable) -> Callable:
             return value of the decorated function.
         """
         futures = [managed_job.future for managed_job
-                   in job_set._managed_jobs if managed_job.future]
+                   in job_set._managed_jobs if managed_job.future]  # type: ignore[unreachable]
         wait(futures)
         return func(job_set, *args, **kwargs)
 
