@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # This code is part of Qiskit.
 #
 # (C) Copyright IBM 2018, 2019.
@@ -52,7 +50,7 @@ def requires_qe_access(func):
           set, it reads the credentials from an alternative set of environment
           variables.
         * if the test is not skipped, it reads `qe_token` and `qe_url` from
-            `Qconfig.py`, environment variables or qiskitrc.
+            environment variables or qiskitrc.
         * if the test is not skipped, it appends `qe_token` and `qe_url` as
             arguments to the test function.
 
@@ -68,7 +66,6 @@ def requires_qe_access(func):
             raise SkipTest('Skipping online tests')
 
         credentials = _get_credentials()
-        obj.using_ibmq_credentials = credentials.is_ibmq()
         kwargs.update({'qe_token': credentials.token,
                        'qe_url': credentials.url})
 
@@ -194,36 +191,69 @@ def requires_device(func):
     @requires_qe_access
     def _wrapper(obj, *args, **kwargs):
 
-        _enable_account(kwargs.pop('qe_token'), kwargs.pop('qe_url'))
-
         backend_name = os.getenv('QE_STAGING_DEVICE', None) if \
             os.getenv('USE_STAGING_CREDENTIALS', '') else os.getenv('QE_DEVICE', None)
 
-        _backend = None
-        provider = _get_custom_provider(IBMQ) or list(IBMQ._providers.values())[0]
-
-        if backend_name:
-            # Put desired provider as the first in the list.
-            providers = [provider] + IBMQ.providers()
-            for provider in providers:
-                backends = provider.backends(name=backend_name)
-                if backends:
-                    _backend = backends[0]
-                    break
-        else:
-            _backend = least_busy(provider.backends(
-                simulator=False, filters=lambda b: b.configuration().n_qubits >= 5))
-
-        if not _backend:
-            raise Exception('Unable to find a suitable backend.')
-
+        _backend = _get_backend(qe_token=kwargs.pop('qe_token'),
+                                qe_url=kwargs.pop('qe_url'),
+                                backend_name=backend_name)
         kwargs.update({'backend': _backend})
-
         return func(obj, *args, **kwargs)
 
     return _wrapper
 
 
+def requires_runtime_device(func):
+    """Decorator that retrieves the appropriate backend to use for testing.
+
+    Args:
+        func (callable): test function to be decorated.
+
+    Returns:
+        callable: the decorated function.
+    """
+    @wraps(func)
+    @requires_qe_access
+    def _wrapper(obj, *args, **kwargs):
+
+        backend_name = os.getenv('QE_STAGING_RUNTIME_DEVICE', None) if \
+            os.getenv('USE_STAGING_CREDENTIALS', '') else os.getenv('QE_RUNTIME_DEVICE', None)
+        if not backend_name:
+            raise SkipTest("Runtime device not specified")
+        _backend = _get_backend(qe_token=kwargs.pop('qe_token'),
+                                qe_url=kwargs.pop('qe_url'),
+                                backend_name=backend_name)
+        kwargs.update({'backend': _backend})
+        return func(obj, *args, **kwargs)
+
+    return _wrapper
+
+
+def _get_backend(qe_token, qe_url, backend_name):
+    """Get the specified backend."""
+    _enable_account(qe_token, qe_url)
+
+    _backend = None
+    provider = _get_custom_provider(IBMQ) or list(IBMQ._providers.values())[0]
+
+    if backend_name:
+        # Put desired provider as the first in the list.
+        providers = [provider] + IBMQ.providers()
+        for provider in providers:
+            backends = provider.backends(name=backend_name)
+            if backends:
+                _backend = backends[0]
+                break
+    else:
+        _backend = least_busy(provider.backends(
+            simulator=False, min_num_qubits=5))
+
+    if not _backend:
+        raise Exception('Unable to find a suitable backend.')
+
+    return _backend
+
+
 def _get_credentials():
     """Finds the credentials for a specific test and options.
 
@@ -278,8 +308,13 @@ def _get_custom_provider(ibmq_factory: IBMQFactory) -> Optional[AccountProvider]
 def _enable_account(qe_token: str, qe_url: str) -> None:
     """Enable the account if one is not already active.
 
-    :param qe_token: API token.
-    :param qe_url: API URL.
+    Args:
+        qe_token: API token.
+        qe_url: API URL.
     """
-    if not IBMQ.active_account():
-        IBMQ.enable_account(qe_token, qe_url)
+    active_account = IBMQ.active_account()
+    if active_account:
+        if active_account.get('token', '') == qe_token:
+            return
+        IBMQ.disable_account()
+    IBMQ.enable_account(qe_token, qe_url)
