@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # This code is part of Qiskit.
 #
 # (C) Copyright IBM 2017, 2020.
@@ -17,34 +15,35 @@
 import time
 import copy
 from datetime import datetime, timedelta
-from unittest import SkipTest
+from unittest import SkipTest, mock, skip
 from threading import Thread, Event
 
-import numpy
-from scipy.stats import chi2_contingency
 from dateutil import tz
 
 from qiskit import ClassicalRegister, QuantumCircuit, QuantumRegister
 from qiskit.test import slow_test
 from qiskit.test.reference_circuits import ReferenceCircuits
-from qiskit.compiler import assemble, transpile
+from qiskit.compiler import transpile
 from qiskit.result import Result
 from qiskit.providers.jobstatus import JobStatus, JOB_FINAL_STATES
 from qiskit.providers.ibmq import least_busy
 from qiskit.providers.ibmq.apiconstants import ApiJobStatus, API_JOB_FINAL_STATES
 from qiskit.providers.ibmq.ibmqbackend import IBMQRetiredBackend
-from qiskit.providers.ibmq.exceptions import IBMQBackendError
+from qiskit.providers.ibmq.exceptions import IBMQBackendError, IBMQBackendApiError
 from qiskit.providers.ibmq.utils.utils import api_status_to_job_status
-from qiskit.providers.ibmq.job.exceptions import IBMQJobInvalidStateError, IBMQJobTimeoutError
+from qiskit.providers.ibmq.job.exceptions import IBMQJobTimeoutError
 from qiskit.providers.ibmq.utils.converters import local_to_utc
+from qiskit.providers.ibmq.api.rest.job import Job as RestJob
+from qiskit.providers.ibmq.api.exceptions import RequestsApiError
 
-from ..jobtestcase import JobTestCase
+from ..ibmqtestcase import IBMQTestCase
 from ..decorators import (requires_provider, requires_device)
-from ..utils import (most_busy_backend, get_large_circuit, bell_in_qobj, cancel_job,
+from ..utils import (most_busy_backend, cancel_job,
                      submit_job_bad_shots, submit_and_cancel, submit_job_one_bad_instr)
+from ..fake_account_client import BaseFakeAccountClient, CancelableFakeJob
 
 
-class TestIBMQJob(JobTestCase):
+class TestIBMQJob(IBMQTestCase):
     """Test ibmqjob module."""
 
     @classmethod
@@ -55,50 +54,17 @@ class TestIBMQJob(JobTestCase):
         super().setUpClass()
         cls.provider = provider
         cls.sim_backend = provider.get_backend('ibmq_qasm_simulator')
-        cls.sim_job = cls.sim_backend.run(
-            bell_in_qobj(backend=cls.sim_backend), validate_qobj=True)
-
-    def test_run_simulator(self):
-        """Test running in a simulator."""
-        qr = QuantumRegister(2, 'q')
-        cr = ClassicalRegister(2, 'c')
-        qc = QuantumCircuit(qr, cr, name='hadamard')
-        qc.h(qr)
-        qc.measure(qr, cr)
-        qobj = assemble(transpile([ReferenceCircuits.bell(), qc], backend=self.sim_backend),
-                        backend=self.sim_backend)
-        shots = qobj.config.shots
-        job = self.sim_backend.run(qobj, validate_qobj=True)
-        result = job.result()
-        counts_qx1 = result.get_counts(0)
-        counts_qx2 = result.get_counts(1)
-        counts_ex1 = {'00': shots / 2, '11': shots / 2}
-        counts_ex2 = {'00': shots / 4, '11': shots / 4, '10': shots / 4, '01': shots / 4}
-        states1 = counts_qx1.keys() | counts_ex1.keys()
-        states2 = counts_qx2.keys() | counts_ex2.keys()
-        # contingency table
-        ctable1 = numpy.array([[counts_qx1.get(key, 0) for key in states1],
-                               [counts_ex1.get(key, 0) for key in states1]])
-        ctable2 = numpy.array([[counts_qx2.get(key, 0) for key in states2],
-                               [counts_ex2.get(key, 0) for key in states2]])
-        self.log.info('states1: %s', str(states1))
-        self.log.info('states2: %s', str(states2))
-        self.log.info('ctable1: %s', str(ctable1))
-        self.log.info('ctable2: %s', str(ctable2))
-        contingency1 = chi2_contingency(ctable1)
-        contingency2 = chi2_contingency(ctable2)
-        self.log.info('chi2_contingency1: %s', str(contingency1))
-        self.log.info('chi2_contingency2: %s', str(contingency2))
-        self.assertGreater(contingency1[1], 0.01)
-        self.assertGreater(contingency2[1], 0.01)
+        cls.bell = transpile(ReferenceCircuits.bell(), cls.sim_backend)
+        cls.sim_job = cls.sim_backend.run(cls.bell)
+        cls.last_month = datetime.now() - timedelta(days=30)
 
     @slow_test
     @requires_device
     def test_run_device(self, backend):
         """Test running in a real device."""
-        qobj = bell_in_qobj(backend=backend, shots=8192)
-        shots = qobj.config.shots
-        job = backend.run(qobj, validate_qobj=True)
+        shots = 8192
+        job = backend.run(transpile(ReferenceCircuits.bell(), backend=backend),
+                          shots=shots)
 
         job.wait_for_final_state(wait=300, callback=self.simple_job_callback)
         result = job.result()
@@ -119,10 +85,9 @@ class TestIBMQJob(JobTestCase):
         for i in range(num_qubits - 1):
             qc.cx(qr[i], qr[i + 1])
         qc.measure(qr, cr)
-        qobj = assemble(transpile([qc] * 20, backend=self.sim_backend),
-                        backend=self.sim_backend, shots=2048)
         num_jobs = 5
-        job_array = [self.sim_backend.run(qobj, validate_qobj=True) for _ in range(num_jobs)]
+        job_array = [self.sim_backend.run(transpile([qc] * 20), shots=2048)
+                     for _ in range(num_jobs)]
         timeout = 30
         start_time = time.time()
         while True:
@@ -140,7 +105,7 @@ class TestIBMQJob(JobTestCase):
                 self.log.info('%s %s %s %s', job.status(), job.status() is JobStatus.RUNNING,
                               check, job.job_id())
             self.log.info('-  %s', str(time.time() - start_time))
-            if time.time() - start_time > timeout:
+            if time.time() - start_time > timeout and self.sim_backend.status().pending_jobs <= 5:
                 raise TimeoutError('Failed to see multiple running jobs after '
                                    '{0} seconds.'.format(timeout))
             time.sleep(0.2)
@@ -167,9 +132,9 @@ class TestIBMQJob(JobTestCase):
         for i in range(num_qubits - 1):
             qc.cx(qr[i], qr[i + 1])
         qc.measure(qr, cr)
-        qobj = assemble(transpile(qc, backend=backend), backend=backend)
         num_jobs = 3
-        job_array = [backend.run(qobj, validate_qobj=True) for _ in range(num_jobs)]
+        job_array = [backend.run(transpile(qc, backend=backend))
+                     for _ in range(num_jobs)]
         time.sleep(3)  # give time for jobs to start (better way?)
         job_status = [job.status() for job in job_array]
         num_init = sum(
@@ -213,15 +178,15 @@ class TestIBMQJob(JobTestCase):
 
     def test_retrieve_jobs(self):
         """Test retrieving jobs."""
-        job_list = self.provider.backends.jobs(
-            backend_name=self.sim_backend.name(), limit=5, skip=0)
+        job_list = self.provider.backend.jobs(
+            backend_name=self.sim_backend.name(), limit=5, skip=0, start_datetime=self.last_month)
         self.assertLessEqual(len(job_list), 5)
         for job in job_list:
             self.assertTrue(isinstance(job.job_id(), str))
 
     def test_retrieve_job(self):
         """Test retrieving a single job."""
-        retrieved_job = self.provider.backends.retrieve_job(self.sim_job.job_id())
+        retrieved_job = self.provider.backend.retrieve_job(self.sim_job.job_id())
         self.assertEqual(self.sim_job.job_id(), retrieved_job.job_id())
         self.assertEqual(self.sim_job.qobj().to_dict(), retrieved_job.qobj().to_dict())
         self.assertEqual(self.sim_job.result().get_counts(), retrieved_job.result().get_counts())
@@ -240,11 +205,8 @@ class TestIBMQJob(JobTestCase):
         if not backend_2:
             raise SkipTest('Skipping test that requires multiple backends')
 
-        qobj_1 = bell_in_qobj(backend=backend_1)
-        job_1 = backend_1.run(qobj_1, validate_qobj=True)
-
-        qobj_2 = bell_in_qobj(backend=backend_2)
-        job_2 = backend_2.run(qobj_2, validate_qobj=True)
+        job_1 = backend_1.run(transpile(ReferenceCircuits.bell(), backend_1))
+        job_2 = backend_2.run(transpile(ReferenceCircuits.bell(), backend_2))
 
         # test a retrieved job's backend is the same as the queried backend
         self.assertEqual(backend_1.retrieve_job(job_1.job_id()).backend().name(),
@@ -269,15 +231,15 @@ class TestIBMQJob(JobTestCase):
     def test_retrieve_job_error(self):
         """Test retrieving an invalid job."""
         self.assertRaises(IBMQBackendError,
-                          self.provider.backends.retrieve_job, 'BAD_JOB_ID')
+                          self.provider.backend.retrieve_job, 'BAD_JOB_ID')
 
     def test_retrieve_jobs_status(self):
         """Test retrieving jobs filtered by status."""
-        # Get the most recent jobs that are done.
         status_args = [JobStatus.DONE, 'DONE', [JobStatus.DONE], ['DONE']]
         for arg in status_args:
             with self.subTest(arg=arg):
-                backend_jobs = self.sim_backend.jobs(limit=5, skip=0, status=arg)
+                backend_jobs = self.sim_backend.jobs(limit=5, skip=5, status=arg,
+                                                     start_datetime=self.last_month)
                 self.assertTrue(backend_jobs)
 
                 for job in backend_jobs:
@@ -303,8 +265,10 @@ class TestIBMQJob(JobTestCase):
 
         for status_filter in status_filters:
             with self.subTest(status_filter=status_filter):
-                job_list = self.sim_backend.jobs(status=status_filter['status'],
-                                                 db_filter=status_filter['db_filter'])
+                job_list = self.sim_backend.jobs(
+                    status=status_filter['status'],
+                    db_filter=status_filter['db_filter'],
+                    start_datetime=self.last_month)
                 job_list_ids = [_job.job_id() for _job in job_list]
                 if job_to_cancel.status() is JobStatus.CANCELLED:
                     self.assertIn(job_to_cancel.job_id(), job_list_ids)
@@ -322,8 +286,7 @@ class TestIBMQJob(JobTestCase):
         active_job_statuses = {api_status_to_job_status(status) for status in ApiJobStatus
                                if status not in API_JOB_FINAL_STATES}
 
-        qobj = bell_in_qobj(backend=backend)
-        job = backend.run(qobj, validate_qobj=True)
+        job = backend.run(transpile(ReferenceCircuits.bell(), backend))
 
         active_jobs = backend.active_jobs()
         if not job.in_final_state():    # Job is still active.
@@ -340,8 +303,7 @@ class TestIBMQJob(JobTestCase):
     def test_retrieve_jobs_queued(self):
         """Test retrieving jobs that are queued."""
         backend = most_busy_backend(self.provider)
-        qobj = bell_in_qobj(backend=backend)
-        job = backend.run(qobj, validate_qobj=True)
+        job = backend.run(transpile(ReferenceCircuits.bell(), backend))
 
         # Wait for the job to queue, run, or reach a final state.
         leave_states = list(JOB_FINAL_STATES) + [JobStatus.QUEUED, JobStatus.RUNNING]
@@ -349,7 +311,8 @@ class TestIBMQJob(JobTestCase):
             time.sleep(0.5)
 
         before_status = job._status
-        job_list_queued = backend.jobs(status=JobStatus.QUEUED, limit=5)
+        job_list_queued = backend.jobs(status=JobStatus.QUEUED, limit=5,
+                                       start_datetime=self.last_month)
         if before_status is JobStatus.QUEUED and job.status() is JobStatus.QUEUED:
             self.assertIn(job.job_id(), [queued_job.job_id() for queued_job in job_list_queued],
                           "job {} is queued but not retrieved when filtering for queued jobs."
@@ -365,8 +328,7 @@ class TestIBMQJob(JobTestCase):
 
     def test_retrieve_jobs_running(self):
         """Test retrieving jobs that are running."""
-        qobj = assemble(transpile(get_large_circuit(backend=self.sim_backend)))
-        job = self.sim_backend.run(qobj, validate_qobj=True)
+        job = self.sim_backend.run(self.bell)
 
         # Wait for the job to run, or reach a final state.
         leave_states = list(JOB_FINAL_STATES) + [JobStatus.RUNNING]
@@ -374,7 +336,8 @@ class TestIBMQJob(JobTestCase):
             time.sleep(0.5)
 
         before_status = job._status
-        job_list_running = self.sim_backend.jobs(status=JobStatus.RUNNING, limit=5)
+        job_list_running = self.sim_backend.jobs(status=JobStatus.RUNNING, limit=5,
+                                                 start_datetime=self.last_month)
         if before_status is JobStatus.RUNNING and job.status() is JobStatus.RUNNING:
             self.assertIn(job.job_id(), [rjob.job_id() for rjob in job_list_running])
 
@@ -389,8 +352,8 @@ class TestIBMQJob(JobTestCase):
         # Add local tz in order to compare to `creation_date` which is tz aware.
         past_month_tz_aware = past_month.replace(tzinfo=tz.tzlocal())
 
-        job_list = self.provider.backends.jobs(backend_name=self.sim_backend.name(),
-                                               limit=2, start_datetime=past_month)
+        job_list = self.provider.backend.jobs(backend_name=self.sim_backend.name(),
+                                              limit=2, start_datetime=past_month)
         self.assertTrue(job_list)
         for job in job_list:
             self.assertGreaterEqual(job.creation_date(), past_month_tz_aware,
@@ -403,8 +366,8 @@ class TestIBMQJob(JobTestCase):
         # Add local tz in order to compare to `creation_date` which is tz aware.
         past_month_tz_aware = past_month.replace(tzinfo=tz.tzlocal())
 
-        job_list = self.provider.backends.jobs(backend_name=self.sim_backend.name(),
-                                               limit=2, end_datetime=past_month)
+        job_list = self.provider.backend.jobs(backend_name=self.sim_backend.name(),
+                                              limit=2, end_datetime=past_month)
         self.assertTrue(job_list)
         for job in job_list:
             self.assertLessEqual(job.creation_date(), past_month_tz_aware,
@@ -427,7 +390,7 @@ class TestIBMQJob(JobTestCase):
 
         for db_filter in db_filters:
             with self.subTest(db_filter=db_filter):
-                job_list = self.provider.backends.jobs(
+                job_list = self.provider.backend.jobs(
                     backend_name=self.sim_backend.name(), limit=2,
                     start_datetime=past_two_month, end_datetime=past_month, db_filter=db_filter)
                 self.assertTrue(job_list)
@@ -443,16 +406,16 @@ class TestIBMQJob(JobTestCase):
         qc = QuantumCircuit(3, 3)
         qc.h(0)
         qc.measure([0, 1, 2], [0, 1, 2])
-        qobj = assemble(transpile(qc, backend=self.sim_backend), backend=self.sim_backend)
-        job = self.sim_backend.run(qobj, validate_qobj=True)
+        job = self.sim_backend.run(transpile(qc, backend=self.sim_backend))
         job.wait_for_final_state()
 
         my_filter = {'backend.name': self.sim_backend.name(),
                      'summaryData.summary.qobj_config.n_qubits': 3,
                      'status': 'COMPLETED'}
 
-        job_list = self.provider.backends.jobs(backend_name=self.sim_backend.name(),
-                                               limit=2, skip=0, db_filter=my_filter)
+        job_list = self.provider.backend.jobs(backend_name=self.sim_backend.name(),
+                                              limit=2, skip=0, db_filter=my_filter,
+                                              start_datetime=self.last_month)
         self.assertTrue(job_list)
 
         for job in job_list:
@@ -464,7 +427,7 @@ class TestIBMQJob(JobTestCase):
 
     def test_pagination_filter(self):
         """Test db_filter that could conflict with pagination."""
-        jobs = self.sim_backend.jobs(limit=25)
+        jobs = self.sim_backend.jobs(limit=25, start_datetime=self.last_month)
         job = jobs[3]
         job_utc = local_to_utc(job.creation_date()).isoformat()
 
@@ -484,19 +447,17 @@ class TestIBMQJob(JobTestCase):
 
     def test_retrieve_jobs_order(self):
         """Test retrieving jobs with different orders."""
-        job = self.sim_backend.run(bell_in_qobj(backend=self.sim_backend), validate_qobj=True)
+        job = self.sim_backend.run(self.bell)
         job.wait_for_final_state()
-        newest_jobs = self.sim_backend.jobs(limit=10, status=JobStatus.DONE, descending=True)
+        newest_jobs = self.sim_backend.jobs(
+            limit=10, status=JobStatus.DONE, descending=True, start_datetime=self.last_month)
         self.assertIn(job.job_id(), [rjob.job_id() for rjob in newest_jobs])
 
-        oldest_jobs = self.sim_backend.jobs(limit=10, status=JobStatus.DONE, descending=False)
+        oldest_jobs = self.sim_backend.jobs(
+            limit=10, status=JobStatus.DONE, descending=False, start_datetime=self.last_month)
         self.assertNotIn(job.job_id(), [rjob.job_id() for rjob in oldest_jobs])
 
-    def test_double_submit_fails(self):
-        """Test submitting a job twice."""
-        with self.assertRaises(IBMQJobInvalidStateError):
-            self.sim_job.submit()
-
+    @skip("Skip until aer issue 1214 is fixed")
     def test_retrieve_failed_job_simulator_partial(self):
         """Test retrieving partial results from a simulator backend."""
         job = submit_job_one_bad_instr(self.sim_backend)
@@ -525,8 +486,7 @@ class TestIBMQJob(JobTestCase):
         excited_sched = x | measure
         schedules = [ground_sched, excited_sched]
 
-        qobj = assemble(schedules, backend, meas_level=1, shots=256)
-        job = backend.run(qobj, validate_qobj=True)
+        job = backend.run(schedules, meas_level=1, shots=256)
         job.wait_for_final_state(wait=300, callback=self.simple_job_callback)
         self.assertTrue(job.done(), "Job {} didn't complete successfully.".format(job.job_id()))
         self.assertIsNotNone(job.result(), "Job {} has no result.".format(job.job_id()))
@@ -536,11 +496,12 @@ class TestIBMQJob(JobTestCase):
         saved_backends = copy.copy(self.provider._backends)
         try:
             del self.provider._backends[self.sim_backend.name()]
-            new_job = self.provider.backends.retrieve_job(self.sim_job.job_id())
+            new_job = self.provider.backend.retrieve_job(self.sim_job.job_id())
             self.assertTrue(isinstance(new_job.backend(), IBMQRetiredBackend))
             self.assertNotEqual(new_job.backend().name(), 'unknown')
 
-            new_job2 = self.provider.backends.jobs(db_filter={'id': self.sim_job.job_id()})[0]
+            new_job2 = self.provider.backend.jobs(
+                db_filter={'id': self.sim_job.job_id()}, start_datetime=self.last_month)[0]
             self.assertTrue(isinstance(new_job2.backend(), IBMQRetiredBackend))
             self.assertNotEqual(new_job2.backend().name(), 'unknown')
         finally:
@@ -564,8 +525,7 @@ class TestIBMQJob(JobTestCase):
         self.assertDictEqual(cached_result, result.to_dict())
         self.assertNotEqual(result.results[0].header.name, 'modified_result')
 
-    @requires_device
-    def test_wait_for_final_state(self, backend):
+    def test_wait_for_final_state(self):
         """Test waiting for job to reach final state."""
 
         def final_state_callback(c_job_id, c_status, c_job, **kwargs):
@@ -594,34 +554,36 @@ class TestIBMQJob(JobTestCase):
             exit_event.wait(wait)
             cancel_job(job_)
 
-        qc = get_large_circuit(backend)
-        qobj = assemble(transpile(qc, backend=backend), backend=backend)
+        wait_args = [2, None]
 
-        wait_args = [5, None]
-        for wait_time in wait_args:
-            with self.subTest(wait_time=wait_time):
-                # Put callback data in a dictionary to make it mutable.
-                callback_info = {'called': False, 'last call time': 0.0, 'last data': {}}
-                cancel_event = Event()
-                job = backend.run(qobj, validate_qobj=True)
-                # Cancel the job after a while.
-                Thread(target=job_canceller, args=(job, cancel_event, 60), daemon=True).start()
-                try:
-                    job.wait_for_final_state(timeout=90, wait=wait_time,
-                                             callback=final_state_callback)
-                    self.assertTrue(job.in_final_state())
-                    self.assertTrue(callback_info['called'])
-                    cancel_event.set()
-                finally:
-                    # Ensure all threads ended.
-                    for thread in job._executor._threads:
-                        thread.join(0.1)
+        saved_api = self.sim_backend._api_client
+        try:
+            self.sim_backend._api_client = BaseFakeAccountClient(job_class=CancelableFakeJob)
+            for wait_time in wait_args:
+                with self.subTest(wait_time=wait_time):
+                    # Put callback data in a dictionary to make it mutable.
+                    callback_info = {'called': False, 'last call time': 0.0, 'last data': {}}
+                    cancel_event = Event()
+                    job = self.sim_backend.run(self.bell)
+                    # Cancel the job after a while.
+                    Thread(target=job_canceller, args=(job, cancel_event, 7), daemon=True).start()
+                    try:
+                        job.wait_for_final_state(timeout=10, wait=wait_time,
+                                                 callback=final_state_callback)
+                        self.assertTrue(job.in_final_state())
+                        self.assertTrue(callback_info['called'])
+                        cancel_event.set()
+                    finally:
+                        # Ensure all threads ended.
+                        for thread in job._executor._threads:
+                            thread.join(0.1)
+        finally:
+            self.sim_backend._api_client = saved_api
 
     def test_wait_for_final_state_timeout(self):
         """Test waiting for job to reach final state times out."""
         backend = most_busy_backend(self.provider)
-        qobj = bell_in_qobj(backend=backend)
-        job = backend.run(qobj, validate_qobj=True)
+        job = backend.run(transpile(ReferenceCircuits.bell(), backend=backend))
         try:
             self.assertRaises(IBMQJobTimeoutError, job.wait_for_final_state, timeout=0.1)
         finally:
@@ -629,3 +591,39 @@ class TestIBMQJob(JobTestCase):
             for thread in job._executor._threads:
                 thread.join(0.1)
             cancel_job(job)
+
+    def test_job_submit_partial_fail(self):
+        """Test job submit partial fail."""
+        job_id = []
+
+        def _side_effect(self, *args, **kwargs):
+            # pylint: disable=unused-argument
+            job_id.append(self.job_id)
+            raise RequestsApiError('Kaboom')
+
+        fail_points = ['put_object_storage', 'callback_upload']
+
+        for fail_method in fail_points:
+            with self.subTest(fail_method=fail_method):
+                with mock.patch.object(RestJob, fail_method,
+                                       side_effect=_side_effect, autospec=True):
+                    with self.assertRaises(IBMQBackendApiError):
+                        self.sim_backend.run(self.bell)
+
+                self.assertTrue(job_id, "Job ID not saved.")
+                job = self.sim_backend.retrieve_job(job_id[0])
+                self.assertEqual(job.status(), JobStatus.CANCELLED,
+                                 f"Job {job.job_id()} status is {job.status()} and not cancelled!")
+
+    def test_job_circuits(self):
+        """Test job circuits."""
+        self.assertEqual(str(self.bell), str(self.sim_job.circuits()[0]))
+
+    def test_job_backend_options(self):
+        """Test job backend options."""
+        run_config = {'shots': 2048, 'memory': True}
+        job = self.sim_backend.run(self.bell, **run_config)
+        self.assertLessEqual(run_config.items(), job.backend_options().items())
+
+    def test_job_header(self):
+        """Test job header."""
