@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # This code is part of Qiskit.
 #
 # (C) Copyright IBM 2017, 2018.
@@ -402,7 +400,7 @@ class TestIBMQJobStates(JobTestCase):
         """Creates a new ``IBMQJob`` running with the provided API object."""
         backend = IBMQBackend(mock.Mock(), mock.Mock(), mock.Mock(), api_client=api)
         self._current_api = api
-        self._current_qjob = backend.run(qobj=FakeQobj(), validate_qobj=True)
+        self._current_qjob = backend.run(qobj=FakeQobj())  # pylint: disable=no-value-for-parameter
         self._current_qjob.refresh = mock.Mock()
         return self._current_qjob
 
