@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # This code is part of Qiskit.
 #
 # (C) Copyright IBM 2019, 2020.
@@ -19,6 +17,7 @@ import time
 from inspect import getfullargspec, isfunction
 import uuid
 from concurrent.futures import wait
+from datetime import datetime, timedelta
 
 from qiskit import QuantumCircuit
 from qiskit.result import Result
@@ -27,7 +26,7 @@ from qiskit.providers.ibmq.managed.ibmqjobmanager import IBMQJobManager
 from qiskit.providers.ibmq.managed.managedresults import ManagedResults
 from qiskit.providers.ibmq.managed import managedjob
 from qiskit.providers.ibmq.managed.exceptions import (
-    IBMQJobManagerJobNotFound, IBMQManagedResultDataNotAvailable, IBMQJobManagerInvalidStateError)
+    IBMQJobManagerJobNotFound, IBMQManagedResultDataNotAvailable)
 from qiskit.providers.jobstatus import JobStatus
 from qiskit.test.reference_circuits import ReferenceCircuits
 
@@ -49,6 +48,7 @@ class TestIBMQJobManager(IBMQTestCase):
         super().setUpClass()
         cls.provider = provider
         cls.sim_backend = provider.get_backend('ibmq_qasm_simulator')
+        cls.last_week = datetime.now() - timedelta(days=7)
 
     def setUp(self):
         """Initial test setup."""
@@ -64,7 +64,7 @@ class TestIBMQJobManager(IBMQTestCase):
         if self._fake_api_backend:
             self._fake_api_backend._api_client.tear_down()
         # Restore provider backends since we cannot deep copy provider.
-        self.provider.backends._provider = self.provider
+        self.provider.backend._provider = self.provider
 
     @property
     def fake_api_backend(self):
@@ -75,7 +75,7 @@ class TestIBMQJobManager(IBMQTestCase):
             self._fake_api_provider._api_client = self._fake_api_backend._api_client \
                 = BaseFakeAccountClient()
             self._fake_api_backend._provider = self._fake_api_provider
-            self._fake_api_provider.backends._provider = self._fake_api_provider
+            self._fake_api_provider.backend._provider = self._fake_api_provider
             self._fake_api_backend._configuration.max_experiments = 10
         return self._fake_api_backend
 
@@ -142,7 +142,7 @@ class TestIBMQJobManager(IBMQTestCase):
         jobs = job_set.jobs()
         job_set.results()
         for i, qobj in enumerate(job_set.qobjs()):
-            rjob = self.fake_api_provider.backends.retrieve_job(jobs[i].job_id())
+            rjob = self.fake_api_provider.backend.retrieve_job(jobs[i].job_id())
             self.maxDiff = None  # pylint: disable=invalid-name
             self.assertDictEqual(qobj.to_dict(), rjob.qobj().to_dict())
 
@@ -238,21 +238,6 @@ class TestIBMQJobManager(IBMQTestCase):
                 rjob_set.results()
                 self.assertEqual(rjob_set.statuses(), [JobStatus.DONE]*len(job_set.jobs()))
 
-    def test_share_job_in_project(self):
-        """Test sharing managed jobs within a project."""
-        job_set = self._jm.run([self._qc]*2, backend=self.fake_api_backend,
-                               max_experiments_per_job=1, job_share_level="project")
-        for job in job_set.jobs():
-            job.refresh()
-            self.assertEqual(job.share_level(), 'project',
-                             "Job {} has incorrect share level".format(job.job_id()))
-
-    def test_invalid_job_share_level(self):
-        """Test setting a non existent share level for managed jobs."""
-        self.assertRaises(IBMQJobManagerInvalidStateError, self._jm.run,
-                          [self._qc]*2, backend=self.fake_api_backend,
-                          job_share_level="invalid_job_share_level")
-
     def test_job_tags(self):
         """Test job tags for managed jobs."""
         job_tags = [uuid.uuid4().hex]
@@ -262,7 +247,7 @@ class TestIBMQJobManager(IBMQTestCase):
         while JobStatus.INITIALIZING in job_set.statuses():
             time.sleep(1)
 
-        rjobs = self.provider.backends.jobs(job_tags=job_tags)
+        rjobs = self.provider.backend.jobs(job_tags=job_tags, start_datetime=self.last_week)
         self.assertEqual({job.job_id() for job in job_set.jobs()},
                          {rjob.job_id() for rjob in rjobs},
                          "Unexpected jobs retrieved. Job tag used was {}".format(job_tags))
