@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # This code is part of Qiskit.
 #
 # (C) Copyright IBM 2017, 2018.
@@ -14,11 +12,16 @@
 
 """Test IBM Quantum online QASM simulator."""
 
+from unittest import mock
+import copy
+
 from qiskit import ClassicalRegister, QuantumCircuit, QuantumRegister
-from qiskit.compiler import assemble, transpile
+from qiskit.compiler import transpile, assemble
+from qiskit.test.reference_circuits import ReferenceCircuits
+from qiskit.providers.aer.noise import NoiseModel
 
 from ..ibmqtestcase import IBMQTestCase
-from ..decorators import requires_provider
+from ..decorators import requires_provider, requires_device
 
 
 class TestIbmqQasmSimulator(IBMQTestCase):
@@ -30,7 +33,7 @@ class TestIbmqQasmSimulator(IBMQTestCase):
         # pylint: disable=arguments-differ
         super().setUp()
         self.provider = provider
-        self.sim_backend = self.provider.get_backend(simulator=True)
+        self.sim_backend = self.provider.get_backend('ibmq_qasm_simulator')
 
     def test_execute_one_circuit_simulator_online(self):
         """Test execute_one_circuit_simulator_online."""
@@ -39,10 +42,9 @@ class TestIbmqQasmSimulator(IBMQTestCase):
         qc = QuantumCircuit(qr, cr, name='qc')
         qc.h(qr[0])
         qc.measure(qr[0], cr[0])
-        qobj = assemble(transpile(qc, backend=self.sim_backend, seed_transpiler=73846087),
-                        backend=self.sim_backend)
-        shots = qobj.config.shots
-        job = self.sim_backend.run(qobj, validate_qobj=True)
+        circs = transpile(qc, backend=self.sim_backend, seed_transpiler=73846087)
+        shots = 1024
+        job = self.sim_backend.run(circs, shots=shots)
         result = job.result()
         counts = result.get_counts(qc)
         target = {'0': shots / 2, '1': shots / 2}
@@ -63,9 +65,8 @@ class TestIbmqQasmSimulator(IBMQTestCase):
         qcr2.measure(qr[0], cr[0])
         qcr2.measure(qr[1], cr[1])
         shots = 1024
-        qobj = assemble(transpile([qcr1, qcr2], backend=self.sim_backend, seed_transpiler=73846087),
-                        backend=self.sim_backend, shots=shots)
-        job = self.sim_backend.run(qobj, validate_qobj=True)
+        circs = transpile([qcr1, qcr2], backend=self.sim_backend, seed_transpiler=73846087)
+        job = self.sim_backend.run(circs, shots=shots)
         result = job.result()
         counts1 = result.get_counts(qcr1)
         counts2 = result.get_counts(qcr2)
@@ -94,9 +95,8 @@ class TestIbmqQasmSimulator(IBMQTestCase):
         qcr2.measure(qr1[1], cr1[1])
         qcr2.measure(qr2[0], cr2[0])
         qcr2.measure(qr2[1], cr2[1])
-        qobj = assemble(transpile([qcr1, qcr2], self.sim_backend, seed_transpiler=8458),
-                        backend=self.sim_backend, shots=1024)
-        job = self.sim_backend.run(qobj, validate_qobj=True)
+        circs = transpile([qcr1, qcr2], self.sim_backend, seed_transpiler=8458)
+        job = self.sim_backend.run(circs, shots=1024)
         result = job.result()
         result1 = result.get_counts(qcr1)
         result2 = result.get_counts(qcr2)
@@ -113,7 +113,47 @@ class TestIbmqQasmSimulator(IBMQTestCase):
         circuit.measure(qr[0], cr[0])
         circuit.x(qr[0]).c_if(cr, 1)
 
-        qobj = assemble(transpile(circuit, backend=self.sim_backend))
-        result = self.sim_backend.run(qobj, validate_qobj=True).result()
-
+        result = self.sim_backend.run(transpile(circuit, backend=self.sim_backend)).result()
         self.assertEqual(result.get_counts(circuit), {'0001': 1024})
+
+    def test_new_sim_method(self):
+        """Test new simulator methods."""
+        def _new_submit(qobj, *args, **kwargs):
+            # pylint: disable=unused-argument
+            self.assertEqual(qobj.config.method, 'extended_stabilizer',
+                             f"qobj header={qobj.header}")
+            return mock.MagicMock()
+
+        backend = copy.deepcopy(self.sim_backend)
+        backend._configuration._data['simulation_method'] = 'extended_stabilizer'
+        backend._submit_job = _new_submit
+
+        circ = transpile(ReferenceCircuits.bell(), backend=backend)
+        backend.run(circ, header={'test': 'circuits'})
+        qobj = assemble(circ, backend=backend, header={'test': 'qobj'})
+        backend.run(qobj)
+
+    def test_new_sim_method_no_overwrite(self):
+        """Test custom method option is not overwritten."""
+        def _new_submit(qobj, *args, **kwargs):
+            # pylint: disable=unused-argument
+            self.assertEqual(qobj.config.method, 'my_method', f"qobj header={qobj.header}")
+            return mock.MagicMock()
+
+        backend = copy.deepcopy(self.sim_backend)
+        backend._configuration._data['simulation_method'] = 'extended_stabilizer'
+        backend._submit_job = _new_submit
+
+        circ = transpile(ReferenceCircuits.bell(), backend=backend)
+        backend.run(circ, method='my_method', header={'test': 'circuits'})
+        qobj = assemble(circ, backend=backend, method='my_method', header={'test': 'qobj'})
+        backend.run(qobj)
+
+    @requires_device
+    def test_simulator_with_noise_model(self, backend):
+        """Test using simulator with a noise model."""
+        noise_model = NoiseModel.from_backend(backend)
+        result = self.sim_backend.run(
+            transpile(ReferenceCircuits.bell(), backend=self.sim_backend),
+            noise_model=noise_model).result()
+        self.assertTrue(result)
